@@ -1,4 +1,10 @@
-from .schema import TableSchemaOpts, ModelSchemaOpts, TableSchema, ModelSchema
+from .schema import (
+    SQLAlchemySchema,
+    SQLAlchemyAutoSchema,
+    SQLAlchemySchemaOpts,
+    SQLAlchemyAutoSchemaOpts,
+    auto_field,
+)
 
 from .convert import (
     ModelConverter,
@@ -9,12 +15,13 @@ from .convert import (
 )
 from .exceptions import ModelConversionError
 
-__version__ = "0.19.0"
+__version__ = "0.26.1"
 __all__ = [
-    "TableSchema",
-    "ModelSchema",
-    "TableSchemaOpts",
-    "ModelSchemaOpts",
+    "SQLAlchemySchema",
+    "SQLAlchemyAutoSchema",
+    "SQLAlchemySchemaOpts",
+    "SQLAlchemyAutoSchemaOpts",
+    "auto_field",
     "ModelConverter",
     "fields_for_model",
     "property2field",
